@@ -28,6 +28,8 @@ var util    = require( './util' ),
     Warning = require( './warn' ).Warning,
     Symbol  = require( './util/Symbol' ),
 
+    parseKeywords = require( './prop_parser' ).parseKeywords,
+
     hasOwn = Object.prototype.hasOwnProperty,
 
 
@@ -50,15 +52,27 @@ var util    = require( './util' ),
     /**
      * Hash of reserved members
      *
-     * These methods cannot be defined in the class. They are for internal use
-     * only. We must check both properties and methods to ensure that neither is
-     * defined.
+     * These methods cannot be defined in the class; they are for internal
+     * use only. We must check both properties and methods to ensure that
+     * neither is defined.
      *
      * @type {Object.<string,boolean>}
      */
     reserved_members = {
         '__initProps': true,
-        'constructor': true,
+    },
+
+    /**
+     * Hash of aliased members
+     *
+     * These are members that alias to another.  Ideally, this should be a
+     * very small list.  It is useful for introducing features without
+     * deprecating old.
+     *
+     * @type {Object.<string,string>}
+     */
+    aliased_members = {
+        'constructor': '__construct',
     },
 
     /**
@@ -641,12 +655,56 @@ exports.prototype.buildMembers = function buildMembers(
         parser.method   && hjoin( 'method', handlers.method );
     }
 
+    handlers.keywordParser = _keywordParser;
+
     // parse members and process accumulated member state
     util.propParse( props, handlers, context );
     this._memberBuilder.end( context.state );
 }
 
 
+/**
+ * Member keyword parser
+ *
+ * In reality, this parser is simply intended to override names where there
+ * are applicable aliases; all keyword parsing is kept to the original
+ * implementation.
+ *
+ * @param {string} prop property to parse
+ *
+ * @return  {{name: string, bitwords: number, keywords: Object.<string, boolean>}}
+ */
+function _keywordParser( prop )
+{
+    var result = parseKeywords( prop ),
+        alias  = _getMemberAlias( result.name );
+
+    if ( alias !== undefined )
+    {
+        result.name = alias;
+    }
+
+    return result;
+}
+
+
+/**
+ * Return a member alias for NAME
+ *
+ * If NAME has no alias, then the result is `undefined`.
+ *
+ * @param {string} name member name
+ *
+ * @return {string|undefined}
+ */
+function _getMemberAlias( name )
+{
+    return ( hasOwn.call( aliased_members, name ) )
+        ? aliased_members[ name ]
+        : undefined;
+}
+
+
 function _parseEach( name, value, keywords )
 {
     var defs = this.defs;
@@ -764,6 +822,12 @@ function _parseMethod( name, func, is_abstract, keywords )
     {
         this.virtual_members[ name ] = true;
     }
+    else
+    {
+        // final (non-virtual) definitions must clear the virtual flag from
+        // their super method
+        delete this.virtual_members[ name ];
+    }
 }
 
 
@@ -1427,6 +1491,9 @@ exports.getMethodInstance = function( inst, cid )
 /**
  * Attaches isAbstract() method to the class
  *
+ * The method returns whether the class contains abstract methods (and is
+ * therefore abstract).
+ *
  * @param  {Function}  func     function (class) to attach method to
  * @param  {Array}     methods  abstract method names
  *
@@ -1436,12 +1503,6 @@ function attachAbstract( func, methods )
 {
     var is_abstract = ( methods.__length > 0 ) ? true: false;
 
-    /**
-     * Returns whether the class contains abstract methods (and is therefore
-     * abstract)
-     *
-     * @return  {boolean}  true if class is abstract, otherwise false
-     */
     util.defineSecureProp( func, 'isAbstract', function()
     {
         return is_abstract;
