@@ -486,9 +486,13 @@ function createImplement( base, ifaces, cname )
  *                                       with implicit extend)
  *
  * @return  {Function}  staging object for mixin
+ *
+ * @throws  {TypeError}  when object is not a trait
  */
 function createUse( basef, traits, nonbase )
 {
+    _validateTraits( traits );
+
     // invoking the partially applied class will immediately complete its
     // definition and instantiate it with the provided constructor arguments
     var partial = function()
@@ -575,6 +579,30 @@ function createUse( basef, traits, nonbase )
 }
 
 
+/**
+ * Verify that each object in TRAITS will be able to be mixed in
+ *
+ * TODO: Use Trait.isTrait; we have circular dependency issues at the moment
+ * preventing that; refactoring is needed.
+ *
+ * @param  {Array}  traits  objects to validate
+ *
+ * @return  {undefined}
+ *
+ * @throws  {TypeError}  when object is not a trait
+ */
+function _validateTraits( traits )
+{
+    for ( var t in traits )
+    {
+        if ( typeof traits[ t ].__mixin !== 'function' )
+        {
+            throw TypeError( "Cannot mix in non-trait " + t );
+        }
+    }
+}
+
+
 function createMixedClass( base, traits )
 {
     // generated definition for our [abstract] class that will mix in each
@@ -717,22 +745,15 @@ function setupProps( func )
 /**
  * Attaches extend method to the given function (class)
  *
+ * This is a shorthand method that can be invoked on the object, rather than
+ * having to call Class.extend( this ).
+ *
  * @param  {Function}  func  function (class) to attach method to
  *
  * @return  {undefined}
  */
 function attachExtend( func )
 {
-    /**
-     * Shorthand for extending classes
-     *
-     * This method can be invoked on the object, rather than having to call
-     * Class.extend( this ).
-     *
-     * @param  {Object}  props  properties to add to extended class
-     *
-     * @return  {Object}  extended class
-     */
     util.defineSecureProp( func, 'extend', function( props )
     {
         return extend( this, props );
